@@ -2,8 +2,7 @@ package Dotiac::DTL::Addon::customtext;
 
 #for testing {% load %}
 
-sub import {
-}
+sub import {}
 sub unimport {}
 
 package Dotiac::DTL::Filter;
